import React, { FunctionComponent, useState } from 'react';

import { preventDefault } from '../common/dom';
import { TranslatedString, withLanguage, WithLanguageProps } from '../locale';

import { AddressSelectProps } from './AddressSelect';
import StaticAddress from './StaticAddress';

import B3Checkout from '../b3checkout';

type AddressSelectButtonProps = Pick<AddressSelectProps, 'selectedAddress' | 'addresses'>;
interface B3Props {
    b3Company: any;
    isB3User: boolean;
}

const AddressSelectButton: FunctionComponent<AddressSelectButtonProps & WithLanguageProps & B3Props> = ({
    selectedAddress,
    language,
    isB3User,
}) => {
    const [ariaExpanded, setAriaExpanded] = useState(false);

    return (
    <a
        aria-controls="addressDropdown"
        aria-description={ language.translate('address.enter_or_select_address_action') }
        aria-expanded={ ariaExpanded }
        className="button dropdown-button dropdown-toggle--select"
        href="#"
        id="addressToggle"
        onClick={ preventDefault(() => setAriaExpanded(!ariaExpanded)) }
    >
        { selectedAddress ?
            <StaticAddress address={ selectedAddress } /> : isB3User 
            ? B3Checkout.locales.tips['b3.addresses.select']
            : <TranslatedString id="address.enter_address_action" /> }
    </a>
)};

export default withLanguage(AddressSelectButton);
